// define if using HPS
`undef ENABLE_HPS

module fpga (

      ///////// ADC /////////
      inout              adc_cs_n,
      output             adc_din,
      input              adc_dout,
      output             adc_sclk,

      ///////// AUD /////////
      input              aud_adcdat,
      inout              aud_adclrck,
      inout              aud_bclk,
      output             aud_dacdat,
      inout              aud_daclrck,
      output             aud_xck,

      ///////// CLOCK2 /////////
      input              clock2_50,
      ///////// CLOCK3 /////////
      input              clock3_50,
      ///////// CLOCK4 /////////
      input              clock4_50,
      ///////// CLOCK /////////
      input              clock_50,

      ///////// DRAM /////////
      output[12:0]       dram_addr,
      output[1:0]        dram_ba,
      output             dram_cas_n,
      output             dram_cke,
      output             dram_clk,
      output             dram_cs_n,
      inout[15:0]        dram_dq,
      output             dram_ldqm,
      output             dram_ras_n,
      output             dram_udqm,
      output             dram_we_n,

      ///////// FAN /////////
      output             fan_ctrl,

      ///////// FPGA /////////
      output             fpga_i2c_sclk,
      inout              fpga_i2c_sdat,

      ///////// GPIO /////////
      inout[35:0]         gpio_0,
      inout[35:0]         gpio_1,


      ///////// 7 seg /////////
      output[6:0]        hex0,
      ///////// hex1 /////////
      output[6:0]        hex1,
      ///////// hex2 /////////
      output[6:0]        hex2,
      ///////// hex3 /////////
      output[6:0]        hex3,
      ///////// hex4 /////////
      output[6:0]        hex4,
      ///////// hex5 /////////
      output[6:0]        hex5,

`ifdef ENABLE_HPS
      ///////// HPS /////////
      inout              hps_conv_usb_n,
      output[14:0]       hps_ddr3_addr,
      output[2:0]        hps_ddr3_ba,
      output             hps_ddr3_cas_n,
      output             hps_ddr3_cke,
      output             hps_ddr3_ck_n,
      output             hps_ddr3_ck_p,
      output             hps_ddr3_cs_n,
      output[3:0]        hps_ddr3_dm,
      inout[31:0]        hps_ddr3_dq,
      inout[3:0]         hps_ddr3_dqs_n,
      inout[3:0]         hps_ddr3_dqs_p,
      output             hps_ddr3_odt,
      output             hps_ddr3_ras_n,
      output             hps_ddr3_reset_n,
      input              hps_ddr3_rzq,
      output             hps_ddr3_we_n,
      output             hps_enet_gtx_clk,
      inout              hps_enet_int_n,
      output             hps_enet_mdc,
      inout              hps_enet_mdio,
      input              hps_enet_rx_clk,
      input[3:0]         hps_enet_rx_data,
      input              hps_enet_rx_dv,
      output[3:0]        hps_enet_tx_data,
      output             hps_enet_tx_en,
      inout[3:0]         hps_flash_data,
      output             hps_flash_dclk,
      output             hps_flash_ncso,
      inout              hps_gsensor_int,
      inout              hps_i2c1_sclk,
      inout              hps_i2c1_sdat,
      inout              hps_i2c2_sclk,
      inout              hps_i2c2_sdat,
      inout              hps_i2c_control,
      inout              hps_key,
      inout              hps_led,
      inout              hps_ltc_gpio,
      output             hps_sd_clk,
      inout              hps_sd_cmd,
      inout[3:0]         hps_sd_data,
      output             hps_spim_clk,
      input              hps_spim_miso,
      output             hps_spim_mosi,
      inout              hps_spim_ss,
      input              hps_uart_rx,
      output             hps_uart_tx,
      input              hps_usb_clkout,
      inout[7:0]         hps_usb_data,
      input              hps_usb_dir,
      input              hps_usb_nxt,
      output             hps_usb_stp,
`endif /*ENABLE_HPS*/

      ///////// IRDA /////////
      input              irda_rxd,
      output             irda_txd,
      ///////// key /////////
      input       [3:0]  key,
      //
      ///////// ledr /////////
      output[9:0]        ledr,

      ///////// PS2 /////////
      inout              ps2_clk,
      inout              ps2_clk2,
      inout              ps2_dat,
      inout              ps2_dat2,

      ///////// sw /////////
      input[9:0]         sw,

      ///////// TD /////////
      input              td_clk27,
      input[7:0]         td_data,
      input              td_hs,
      output             td_reset_n,
      input              td_vs,

      ///////// VGA /////////
      output[7:0]        vga_b,
      output             vga_blank_n,
      output             vga_clk,
      output[7:0]        vga_g,
      output             vga_hs,
      output[7:0]        vga_r,
      output             vga_sync_n,
      output             vga_vs
);



//    Turn seven segments and leds
assign    hex0        =    7'h7F;
assign    hex1        =    7'h7F;
assign    hex2        =    7'h7F;
assign    hex3        =    7'h7F;
assign    hex4        =    7'h7F;
assign    hex5        =    7'h7F;
assign    ledr        =    10'h0000;


//    Video output
assign  vga_clk       =  0;
assign  vga_hs        =  0;
assign  vga_vs        =  0;
assign  vga_blank_n   =  0;
assign  vga_sync_n    =  0;
assign  vga_r         =  8'hFF;
assign  vga_g         =  8'hFF;
assign  vga_b         =  8'hFF;


//    Unused inouts
assign gpio_0        = 'z;
assign gpio_1        = 'z;

assign adc_cs_n      = 'z;
assign dram_dq       = 'z;
assign fpga_i2c_sdat = 'z;
assign ps2_clk       = 'z;
assign ps2_clk2      = 'z;
assign ps2_dat       = 'z;
assign ps2_dat2      = 'z;
assign aud_adclrck   =  'z;
assign aud_daclrck   =  'z;
assign aud_bclk      =  'z;

endmodule

